package xhttp3.internal.platform;

import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;

class OptionalMethod<T> {
   private final Class<?> returnType;
   private final String methodName;
   private final Class[] methodParams;

   public OptionalMethod(Class<?> returnType, String methodName, Class... methodParams) {
      this.returnType = returnType;
      this.methodName = methodName;
      this.methodParams = methodParams;
   }

   private Method getMethod(Class<?> clazz) {
      Method var2 = null;
      String var3;
      Class var4;
      if ((var3 = this.methodName) != null && (var2 = getPublicMethod(clazz, var3, this.methodParams)) != null && (var4 = this.returnType) != null && !var4.isAssignableFrom(var2.getReturnType())) {
         var2 = null;
      }

      return var2;
   }

   private static Method getPublicMethod(Class<?> clazz, String methodName, Class[] parameterTypes) {
      Class var10000 = clazz;
      String var10001 = methodName;
      Class[] var10002 = parameterTypes;
      Method clazz1 = null;

      Method var6;
      boolean var8;
      try {
         var6 = var10000.getMethod(var10001, var10002);
      } catch (NoSuchMethodException var4) {
         var8 = false;
         return clazz1;
      }

      clazz1 = var6;

      int var7;
      try {
         var7 = var6.getModifiers();
      } catch (NoSuchMethodException var3) {
         var8 = false;
         return clazz1;
      }

      if ((var7 & 1) == 0) {
         clazz1 = null;
      }

      return clazz1;
   }

   public boolean isSupported(T target) {
      return this.getMethod(target.getClass()) != null;
   }

   public Object invokeOptional(T target, Object... args) {
      Method var4;
      if ((var4 = this.getMethod(target.getClass())) == null) {
         return null;
      } else {
         try {
            return var4.invoke(target, args);
         } catch (IllegalAccessException var3) {
            return null;
         }
      }
   }

   public Object invokeOptionalWithoutCheckedException(T target, Object... args) {
      try {
         return this.invokeOptional(target, args);
      } catch (InvocationTargetException var3) {
         Throwable var4;
         if ((var4 = var3.getTargetException()) instanceof RuntimeException) {
            throw (RuntimeException)var4;
         } else {
            AssertionError var10000 = new AssertionError("Unexpected exception");
            var10000.initCause(var4);
            throw var10000;
         }
      }
   }

   public Object invoke(T target, Object... args) {
      Method var3;
      if ((var3 = this.getMethod(target.getClass())) != null) {
         try {
            return var3.invoke(target, args);
         } catch (IllegalAccessException var4) {
            AssertionError var10000 = new AssertionError("Unexpectedly could not call: " + var3);
            var10000.initCause(var4);
            throw var10000;
         }
      } else {
         throw new AssertionError("Method " + this.methodName + " not supported for object " + target);
      }
   }

   public Object invokeWithoutCheckedException(T target, Object... args) {
      try {
         return this.invoke(target, args);
      } catch (InvocationTargetException var3) {
         Throwable var4;
         if ((var4 = var3.getTargetException()) instanceof RuntimeException) {
            throw (RuntimeException)var4;
         } else {
            AssertionError var10000 = new AssertionError("Unexpected exception");
            var10000.initCause(var4);
            throw var10000;
         }
      }
   }
}
